# Python client for TMInterface
[![Documentation Status](https://readthedocs.org/projects/tminterface/badge/?version=latest)](https://tminterface.readthedocs.io/en/latest/?badge=latest)

This is the Python client for TMInterface, which allows for modifying TrackMania state through the TMInterface server API.

**NOTE:** the TMInterface API is not finished and is subject to change.

Install the package with pip: `pip install tminterface`.

Documentation is available on [Read the Docs](https://tminterface.readthedocs.io/en/latest/).